/***************************************************************************
 *   Copyright (C) 2004 by Petr Kavanek                                    *
 *   pietrotk@seznam.cz                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "t_aplikace.h"

//---------------------------------------------------------------------------
// Konstruktor
//---------------------------------------------------------------------------
T_Aplikace::T_Aplikace()
: 
SirkaHlOkna(0),
VyskaHlOkna(0),
OknoSMenu(0),
Menu(0),
Konec(false)
{

} // Konstruktor ------------------------------------------------------------






//---------------------------------------------------------------------------
// main()
//---------------------------------------------------------------------------
int T_Aplikace::main(int argc, char** argv) {
	
	using namespace std;

	// vytvorime okno kanzole a presmerujeme na nej stadndardni vstup/vystup
	CL_ConsoleWindow Konzole("Console");
	Konzole.redirect_stdio();

	try	{

		// Inicializace ClanLibu
		CL_SetupCore::init();
		CL_SetupDisplay::init();
		CL_SetupGL::init();
		CL_SetupGUI::init();


		// Vytvorime GUI pouzivajici stribrny styl a nas GDF soubor
		CL_ResourceManager SpravceZdrojuStStylu("../zdroje/gui_style_silver/gui.xml");
		SpravceZdroju = new CL_ResourceManager("../zdroje/gdf.xml");
		SpravceZdroju->add_resources(SpravceZdrojuStStylu);

		SirkaHlOkna = CL_Integer("SirkaHlOkna", SpravceZdroju);
		VyskaHlOkna = CL_Integer("VyskaHlOkna", SpravceZdroju);
		
		// Vytvoreni hlavniho okna programu
		HlavniOkno = CL_DisplayWindow("Priklad tvormy menu", SirkaHlOkna, VyskaHlOkna, false, true);
				
		
		CL_StyleManager_Silver SpravceStStylu(SpravceZdroju);
		SpravceGUI = new CL_GUIManager(&SpravceStStylu);


				
		// Nacteme komponenty z GDF
		CL_ComponentManager SpravceKomponent("GUI", SpravceZdroju, SpravceGUI);

		// ziskame ukazatele na nektere vybrane komponenety
//		ZiskejUkazateleNaKomponenty(SpravceKomponent);

		// pripojime signaly do slotu
//		PripojSignaly();

		// vytvorime okno s menu
		VytvorMenu();

    // hlavni smycka - ukoncime stiskem ecsape, nebo zavrenim GUI
    while ((! Konec) && ! (CL_Keyboard::get_keycode(CL_KEY_ESCAPE))) {

			CL_Display::clear(CL_Color::white);
			
			SpravceGUI->show();
		
      // zobrazime nakreslene zmeny (prehozeni predniho a zadniho bufferu)
      CL_Display::flip();


      // uspime aplikaci na deset milisekund, abychom zbytecne
      // neblokovali procesor
      const int DobaObnoveni = 10;
      CL_System::sleep(DobaObnoveni);

      // probudime aplikaci resp. knihovnu aby byla aktualni
      CL_System::keep_alive();

    } // while
		
		delete OknoSMenu;

		// uvolnime spravce GUI
		delete SpravceGUI;

		// uvolnime spravce zdroju
		delete SpravceZdroju;

		// Deinicializace Clanlibu
		CL_SetupGL::deinit();
		CL_SetupGUI::deinit();
		CL_SetupDisplay::deinit();
		CL_SetupCore::deinit();
	}
	catch (CL_Error Chyba) {

		// vypiseme chybove hlaseni na konzoli
		std::cout << Chyba.message.c_str() << std::endl;

		// Zobrazime na konzoli ukoncovaci zpravu
		Konzole.display_close_message();
		
	}

	return 0;

} // main() -----------------------------------------------------------------





//---------------------------------------------------------------------------
// VytvorMenu()
//---------------------------------------------------------------------------
void T_Aplikace::VytvorMenu() {

	// vytvorime okno do ktereho posleze umistime menu
	OknoSMenu = new CL_Window(CL_Rect(0, 0, SirkaHlOkna, VyskaHlOkna), "Okno s menu", SpravceGUI);
	
	// vytvorime menu
	Menu = new CL_Menu(OknoSMenu->get_client_area());
	
	// cast odpovidajici prvnimu obrazku
	Menu->create_toggle_item("0,1/0,2/0,4/0,7", "K/B/C/D");
	Menu->create_item("0,1/0,2/0,5", "K/B/E");
	Menu->create_item("0,1/0,2/0,6", "K/B/F");
	Menu->create_item("0,1/0,3", "K/G");
	
	
	// cast odpovidajici druhemu obrazku
	Menu->create_item("1,1/1,2/1,8/1,11", "R/B/H/E");
	Menu->create_toggle_item("1,1/1,2/1,8/1,12", "R/B/H/F");
	Menu->create_item("1,1/1,3", "R/E");
	Menu->create_item("1,1/1,2/1,9", "R/B/C");
	Menu->create_item("1,1/1,4", "R/G");
	Menu->create_item("1,1/1,5", "R/D");
	Menu->create_item("1,1/1,6/1,10", "R/B/C");
	Menu->create_item("1,1/1,7", "R/D");

//	Nasledujici dva radky jsou ekvivalentem k Menu->create_item("2,1/2,2", "X/Y");	
//	CL_MenuNode* Uzel = Menu->create_node("2,1/2,2", "X/Y");
//	new CL_MenuItem("Y", Uzel);

} // VytvorMenu()-------------------------------------------------------------
